import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { environment } from '../../environments/environment';

@Injectable({
  providedIn: 'root'
})
export class DesignApiService {
  private apiUrl = `${environment.apiUrl}/designs`;

  constructor(private http: HttpClient) {}

  // 获取颜色统计数据
  getAllColorsStatistics(): Observable<any> {
    return this.http.get(`${this.apiUrl}/color-statistics`);
  }

  // 记录设计使用
  saveDesign(design: {
    part1: string;
    part2: string;
    part3: string;
    part4: string;
  }): Observable<any> {
    return this.http.post(`${this.apiUrl}/record`, design);
  }

  // 生成测试数据
  generateTestData(count: number): Observable<any> {
    return this.http.post(`${this.apiUrl}/generate-test-data?count=${count}`, {});
  }

  // 重置统计数据
  resetStatistics(): Observable<any> {
    return this.http.post(`${this.apiUrl}/reset-statistics`, {});
  }
}